package org.zeroturnaround.javarebel.integration.support;

import java.io.InputStream;
import java.net.URL;
import java.security.AccessControlContext;
import java.security.AccessController;
import java.security.PrivilegedAction;
import org.zeroturnaround.bundled.javassist.ClassPath;
import org.zeroturnaround.javarebel.LoggerFactory;

/**
 * @author Rein Raudjärv
 */
public class RestrictedClassClassPath implements ClassPath
{
  private AccessControlContext acc;
  private Class thisClass;

  public RestrictedClassClassPath(Class c)
  {
    this.thisClass = c;
    this.acc = AccessController.getContext();
  }

  /**
   * Creates a new instance of system class path.
   */
  RestrictedClassClassPath()
  {
    this(Object.class);
  }
  
  public InputStream openClassfile(String classname)
  {
    final String jarname = "/" + classname.replace('.', '/') + ".class";
    
    return (InputStream) AccessController.doPrivileged(new PrivilegedAction() {
      public Object run() {
        return thisClass.getResourceAsStream(jarname);
      }
    }, acc);
  }

  public URL find(String classname)
  {
    final String jarname = "/" + classname.replace('.', '/') + ".class";
    return (URL) AccessController.doPrivileged(new PrivilegedAction() {
      public Object run() {
        return thisClass.getResource(jarname);
      }
    }, acc);
  }

  public void close()
  {
    this.thisClass = null;
    this.acc = null;
  }
}